import re

import requests
from uritools import urisplit


def hackernews(url, timeout=15, html=None):
    """Returns the comment text and story title.  Domain is prefixed with the submitter/commenter name"""

    id = urisplit(url).getquerydict().get("id")[0]
    item = requests.get(
        f"https://hacker-news.firebaseio.com/v0/item/{id}.json", timeout=timeout
    ).json()

    text = ""
    if "text" in item:
        text = item["text"]
        text = text.replace('<p>', " ")
        text = re.sub('<[^<]+?>', '', text)

    title = ""
    root_item = item
    # find the root submitted post to get the title
    while 1:
        if "title" in root_item:
            title = root_item["title"]
            break
        if "parent" in root_item:
            root_item = requests.get(
                f"https://hacker-news.firebaseio.com/v0/item/{root_item['parent']}.json",
                timeout=timeout,
            ).json()
        else:
            break

    if "title" in item:
        title = item["title"]

    return {
        "url": url,
        "title": title,
        "domain": f"{item['by']} (news.ycombinator.com)",
        "description": text,
        "image": "",
        "favicon": "https://news.ycombinator.com/favicon.ico",
    }


CUSTOM_PROVIDER_LIST = [[r"https://news\.ycombinator\.com/item\?id=[0-9]+", hackernews]]



NOEMBED_PROVIDER_LIST = [
    [
        "https?://(?:[^\\.]+\\.)?(?:youtu\\.be|youtube\\.com/embed)/([a-zA-Z0-9_-]+)",
        "http://noembed.com/embed",
    ],
    [
        "https?://(?:[^\\.]+\\.)?youtube\\.com/watch/?\\?(?:.+&)?v=([^&]+)",
        "http://noembed.com/embed",
    ],
    [
        "https?://www\\.globalgiving\\.org/((micro)?projects|funds)/.*",
        "http://noembed.com/embed",
    ],
    [
        "https?://www\\.giantbomb\\.com/videos/[^/]+/\\d+-\\d+/?",
        "http://noembed.com/embed",
    ],
    ["http://bash\\.org/\\?(\\d+)", "http://noembed.com/embed"],
    ["http://amzn\\.com/([^/]+)", "http://noembed.com/embed"],
    [
        "http://www\\.amazon\\.com/(?:.+/)?[gd]p/(?:product/)?(?:tags-on-product/)?([a-zA-Z0-9]+)",
        "http://noembed.com/embed",
    ],
    ["https://tube.switch.ch/videos/([a-z0-9]+)", "http://noembed.com/embed"],
    ["https?://db\\.tt/[a-zA-Z0-9]+", "http://noembed.com/embed"],
    [
        "https?://www\\.(dropbox\\.com/s/.+\\.(?:jpg|png|gif))",
        "http://noembed.com/embed",
    ],
    ["https?://imgur\\.com/(?:[^\\/]+/)?[0-9a-zA-Z]+$", "http://noembed.com/embed"],
    ["https?://muki\\.io/(embed/)?(.+)", "http://noembed.com/embed"],
    ["https?://vine.co/v/[a-zA-Z0-9]+", "http://noembed.com/embed"],
    [
        "https?://reports\\.zoho\\.com/ZDBDataSheetView\\.cc\\?OBJID=1432535000000003002&STANDALONE=true&INTERVAL=120&DATATYPESYMBOL=false&REMTOOLBAR=false&SEARCHBOX=true&INCLUDETITLE=true&INCLUDEDESC=true&SHOWHIDEOPT=true",
        "http://noembed.com/embed",
    ],
    ["https?://yfrog\\.us/.*", "http://noembed.com/embed"],
    ["https?://.*\\.yfrog\\.com/.*", "http://noembed.com/embed"],
    ["https?://.*\\.wizer\\.me/preview/.*", "http://noembed.com/embed"],
    ["https?://.*\\.wizer\\.me/learn/.*", "http://noembed.com/embed"],
    ["https?://.*\\.wiredrive\\.com/.*", "http://noembed.com/embed"],
    ["https?://vlipsy\\.com/.*", "http://noembed.com/embed"],
    ["https?://player\\.vimeo\\.com/video/.*", "http://noembed.com/embed"],
    ["https?://vimeo\\.com/ondemand/.*/.*", "http://noembed.com/embed"],
    ["https?://vimeo\\.com/groups/.*/videos/.*", "http://noembed.com/embed"],
    ["https?://vimeo\\.com/channels/.*/.*", "http://noembed.com/embed"],
    ["https?://vimeo\\.com/album/.*/video/.*", "http://noembed.com/embed"],
    ["https?://vimeo\\.com/.*", "http://noembed.com/embed"],
    ["https?://vidl\\.it/.*", "http://noembed.com/embed"],
    ["https?://www\\.videojug\\.com/interview/.*", "http://noembed.com/embed"],
    ["https?://www\\.videojug\\.com/film/.*", "http://noembed.com/embed"],
    ["https?://www\\.vevo\\.com/.*", "http://noembed.com/embed"],
    ["https?://veervr\\.tv/videos/.*", "http://noembed.com/embed"],
    ["https?://veer\\.tv/videos/.*", "http://noembed.com/embed"],
    ["https?://uttles\\.com/uttle/.*", "http://noembed.com/embed"],
    ["https?://utposts\\.com/products/.*", "http://noembed.com/embed"],
    ["https?://www\\.utposts\\.com/products/.*", "http://noembed.com/embed"],
    ["https?://.*\\.ustream\\.com/.*", "http://noembed.com/embed"],
    ["https?://.*\\.ustream\\.tv/.*", "http://noembed.com/embed"],
    ["https?://.*\\.uol\\.com\\.br/video/.*", "http://noembed.com/embed"],
    ["https?://.*\\.uol\\.com\\.br/view/.*", "http://noembed.com/embed"],
    ["https?://player\\.ubideo\\.com/.*", "http://noembed.com/embed"],
    ["https?://twitter\\.com/.*/status/.*", "http://noembed.com/embed"],
    ["https?://twitch\\.tv/.*", "http://noembed.com/embed"],
    ["https?://www\\.twitch\\.tv/.*", "http://noembed.com/embed"],
    ["https?://clips\\.twitch\\.tv/.*", "http://noembed.com/embed"],
    ["https?://www\\.topy\\.se/image/.*", "http://noembed.com/embed"],
    ["https?://www\\.tickcounter\\.com/worldclock/.*", "http://noembed.com/embed"],
    ["https?://www\\.tickcounter\\.com/ticker/.*", "http://noembed.com/embed"],
    ["https?://www\\.tickcounter\\.com/countup/.*", "http://noembed.com/embed"],
    ["https?://www\\.tickcounter\\.com/countdown/.*", "http://noembed.com/embed"],
    ["https?://theysaidso\\.com/image/.*", "http://noembed.com/embed"],
    ["https?://.*\\.nytimes\\.com/.*", "http://noembed.com/embed"],
    ["https?://nytimes\\.com/.*", "http://noembed.com/embed"],
    ["https?://www\\.nytimes\\.com/svc/oembed", "http://noembed.com/embed"],
    ["https?://ted\\.com/talks/.*", "http://noembed.com/embed"],
    ["https?://www\\.sway\\.com/.*", "http://noembed.com/embed"],
    ["https?://sway\\.com/.*", "http://noembed.com/embed"],
    ["https?://www\\.sutori\\.com/story/.*", "http://noembed.com/embed"],
    ["https?://content\\.streamonecloud\\.net/embed/.*", "http://noembed.com/embed"],
    ["https?://streamable\\.com/.*", "http://noembed.com/embed"],
    ["https?://.*\\.spreaker\\.com/.*", "http://noembed.com/embed"],
    ["https?://speakerdeck\\.com/.*/.*", "http://noembed.com/embed"],
    ["https?://soundsgood\\.co/playlist/.*", "http://noembed.com/embed"],
    ["https?://play\\.soundsgood\\.co/playlist/.*", "http://noembed.com/embed"],
    ["https?://soundcloud\\.com/.*", "http://noembed.com/embed"],
    ["https?://www\\.socialexplorer\\.com/.*/embed", "http://noembed.com/embed"],
    ["https?://www\\.socialexplorer\\.com/.*/edit", "http://noembed.com/embed"],
    ["https?://www\\.socialexplorer\\.com/.*/view", "http://noembed.com/embed"],
    ["https?://www\\.socialexplorer\\.com/.*/explore", "http://noembed.com/embed"],
    ["https?://.*\\.smugmug\\.com/.*", "http://noembed.com/embed"],
    ["https?://pt\\.slideshare\\.net/.*/.*", "http://noembed.com/embed"],
    ["https?://es\\.slideshare\\.net/.*/.*", "http://noembed.com/embed"],
    ["https?://de\\.slideshare\\.net/.*/.*", "http://noembed.com/embed"],
    ["https?://fr\\.slideshare\\.net/.*/.*", "http://noembed.com/embed"],
    ["https?://www\\.slideshare\\.net/.*/.*", "http://noembed.com/embed"],
    ["https?://sketchfab\\.com/.*/folders/.*", "http://noembed.com/embed"],
    ["https?://sketchfab\\.com/models/.*", "http://noembed.com/embed"],
    ["https?://onsizzle\\.com/i/.*", "http://noembed.com/embed"],
    ["https?://.*\\.silk\\.co/s/embed/.*", "http://noembed.com/embed"],
    ["https?://.*\\.silk\\.co/explore/.*", "http://noembed.com/embed"],
    ["https?://showtheway\\.io/to/.*", "http://noembed.com/embed"],
    ["https?://shoud\\.io/.*", "http://noembed.com/embed"],
    ["https?://shoudio\\.com/.*", "http://noembed.com/embed"],
    ["https?://www\\.shortnote\\.jp/view/notes/.*", "http://noembed.com/embed"],
    ["https?://www\\.scribd\\.com/doc/.*", "http://noembed.com/embed"],
    ["https?://scribblemaps\\.com/maps/view/.*", "http://noembed.com/embed"],
    ["https?://www\\.scribblemaps\\.com/maps/view/.*", "http://noembed.com/embed"],
    ["https?://www\\.screenr\\.com/.*/", "http://noembed.com/embed"],
    ["https?://.*\\.screen9\\.tv/.*", "http://noembed.com/embed"],
    ["https?://console\\.screen9\\.com/.*", "http://noembed.com/embed"],
    ["https?://videos\\.sapo\\.pt/.*", "http://noembed.com/embed"],
    ["https?://roomshare\\.jp/en/post/.*", "http://noembed.com/embed"],
    ["https?://roomshare\\.jp/post/.*", "http://noembed.com/embed"],
    ["https?://www\\.reverbnation\\.com/.*/songs/.*", "http://noembed.com/embed"],
    ["https?://www\\.reverbnation\\.com/.*", "http://noembed.com/embed"],
    [
        "https?://repubhub\\.icopyright\\.net/freePost\\.act\\?.*",
        "http://noembed.com/embed",
    ],
    ["https?://rwire\\.com/.*", "http://noembed.com/embed"],
    ["https?://reddit\\.com/r/.*/comments/.*/.*", "http://noembed.com/embed"],
    ["https?://rapidengage\\.com/s/.*", "http://noembed.com/embed"],
    ["https?://www\\.quizz\\.biz/quizz-.*\\.html", "http://noembed.com/embed"],
    ["https?://www\\.quiz\\.biz/quizz-.*\\.html", "http://noembed.com/embed"],
    ["https?://punters\\.com\\.au/.*", "http://noembed.com/embed"],
    ["https?://www\\.punters\\.com\\.au/.*", "http://noembed.com/embed"],
    ["https?://portfolium\\.com/entry/.*", "http://noembed.com/embed"],
    ["https?://app\\.sellwithport\\.com/#/buyer/.*", "http://noembed.com/embed"],
    ["https?://.*\\.polldaddy\\.com/ratings/.*", "http://noembed.com/embed"],
    ["https?://.*\\.polldaddy\\.com/poll/.*", "http://noembed.com/embed"],
    ["https?://.*\\.polldaddy\\.com/s/.*", "http://noembed.com/embed"],
    ["https?://store\\.pixdor\\.com/map/.*/show", "http://noembed.com/embed"],
    [
        "https?://store\\.pixdor\\.com/place-marker-widget/.*/show",
        "http://noembed.com/embed",
    ],
    ["https?://www\\.pastery\\.net/.*", "http://noembed.com/embed"],
    ["https?://pastery\\.net/.*", "http://noembed.com/embed"],
    ["https?://www\\.oumy\\.com/v/.*", "http://noembed.com/embed"],
    ["https?://orbitvu\\.co/001/.*/1/2/orbittour/.*/view", "http://noembed.com/embed"],
    ["https?://orbitvu\\.co/001/.*/2/orbittour/.*/view", "http://noembed.com/embed"],
    ["https?://orbitvu\\.co/001/.*/ov3602/.*/view", "http://noembed.com/embed"],
    ["https?://orbitvu\\.co/001/.*/ov3601/.*/view", "http://noembed.com/embed"],
    ["https?://orbitvu\\.co/001/.*/ov3601/view", "http://noembed.com/embed"],
    ["https?://on\\.aol\\.com/video/.*", "http://noembed.com/embed"],
    ["https?://official\\.fm/playlists/.*", "http://noembed.com/embed"],
    ["https?://official\\.fm/tracks/.*", "http://noembed.com/embed"],
    ["https?://mix\\.office\\.com/embed/.*", "http://noembed.com/embed"],
    ["https?://mix\\.office\\.com/watch/.*", "http://noembed.com/embed"],
    ["https?://odds\\.com\\.au/.*", "http://noembed.com/embed"],
    ["https?://www\\.odds\\.com\\.au/.*", "http://noembed.com/embed"],
    ["https?://.*\\.nfb\\.ca/film/.*", "http://noembed.com/embed"],
    ["https?://nanoo\\.pro/link/.*", "http://noembed.com/embed"],
    ["https?://.*\\.nanoo\\.pro/link/.*", "http://noembed.com/embed"],
    ["https?://nanoo\\.tv/link/.*", "http://noembed.com/embed"],
    ["https?://.*\\.nanoo\\.tv/link/.*", "http://noembed.com/embed"],
    ["https?://mybeweeg\\.com/w/.*", "http://noembed.com/embed"],
    ["https?://beta\\.modelo\\.io/embedded/.*", "http://noembed.com/embed"],
    ["https?://moby\\.to/.*", "http://noembed.com/embed"],
    ["https?://www\\.mobypicture\\.com/user/.*/view/.*", "http://noembed.com/embed"],
    ["https?://www\\.mixcloud\\.com/.*/.*/", "http://noembed.com/embed"],
    ["https?://meetu\\.ps/.*", "http://noembed.com/embed"],
    ["https?://meetup\\.com/.*", "http://noembed.com/embed"],
    ["https?://me\\.me/i/.*", "http://noembed.com/embed"],
    ["https?://mathembed\\.com/latex\\?inputText=.*", "http://noembed.com/embed"],
    ["https?://learningapps\\.org/.*", "http://noembed.com/embed"],
    ["https?://jdr\\.knacki\\.info/meuh/.*", "http://noembed.com/embed"],
    ["https?://www\\.kitchenbowl\\.com/recipe/.*", "http://noembed.com/embed"],
    ["https?://kit\\.com/.*/.*", "http://noembed.com/embed"],
    ["https?://www\\.kidoju\\.com/fr/x/.*/.*", "http://noembed.com/embed"],
    ["https?://www\\.kidoju\\.com/en/x/.*/.*", "http://noembed.com/embed"],
    ["https?://www\\.kickstarter\\.com/projects/.*", "http://noembed.com/embed"],
    ["https?://www\\.isnare\\.com/.*", "http://noembed.com/embed"],
    ["https?://www\\.instagr\\.am/p/.*", "http://noembed.com/embed"],
    ["https?://www\\.instagram\\.com/p/.*", "http://noembed.com/embed"],
    ["https?://instagr\\.am/p/.*", "http://noembed.com/embed"],
    ["https?://instagram\\.com/p/.*", "http://noembed.com/embed"],
    ["https?://.*\\.inphood\\.com/.*", "http://noembed.com/embed"],
    ["https?://www\\.inoreader\\.com/oembed/", "http://noembed.com/embed"],
    ["https?://infogr\\.am/.*", "http://noembed.com/embed"],
    [
        "https?://player\\.indacolive\\.com/player/jwp/clients/.*",
        "http://noembed.com/embed",
    ],
    ["https?://ifttt\\.com/recipes/.*", "http://noembed.com/embed"],
    ["https?://www\\.ifixit\\.com/Guide/View/.*", "http://noembed.com/embed"],
    ["https?://www\\.hulu\\.com/watch/.*", "http://noembed.com/embed"],
    ["https?://huffduffer\\.com/.*/.*", "http://noembed.com/embed"],
    ["https?://gyazo\\.com/.*", "http://noembed.com/embed"],
    ["https?://media\\.giphy\\.com/media/.*/giphy\\.gif", "http://noembed.com/embed"],
    ["https?://gph\\.is/.*", "http://noembed.com/embed"],
    ["https?://giphy\\.com/gifs/.*", "http://noembed.com/embed"],
    ["https?://www\\.gfycat\\.com/.*", "http://noembed.com/embed"],
    ["https?://gfycat\\.com/.*", "http://noembed.com/embed"],
    ["https?://gty\\.im/.*", "http://noembed.com/embed"],
    ["https?://germany\\.geograph\\.org/.*", "http://noembed.com/embed"],
    ["https?://geo\\.hlipp\\.de/.*", "http://noembed.com/embed"],
    ["https?://geo-en\\.hlipp\\.de/.*", "http://noembed.com/embed"],
    ["https?://.*\\.channel\\.geographs\\.org/.*", "http://noembed.com/embed"],
    ["https?://channel-islands\\.geographs\\.org/.*", "http://noembed.com/embed"],
    ["https?://channel-islands\\.geograph\\.org/.*", "http://noembed.com/embed"],
    ["https?://.*\\.geograph\\.org\\.je/.*", "http://noembed.com/embed"],
    ["https?://.*\\.geograph\\.org\\.gg/.*", "http://noembed.com/embed"],
    [
        "https?://.*\\.wikimedia\\.org/.*_geograph\\.org\\.uk_.*",
        "http://noembed.com/embed",
    ],
    ["https?://.*\\.geograph\\.ie/.*", "http://noembed.com/embed"],
    ["https?://.*\\.geograph\\.co\\.uk/.*", "http://noembed.com/embed"],
    ["https?://.*\\.geograph\\.org\\.uk/.*", "http://noembed.com/embed"],
    ["https?://www\\.funnyordie\\.com/videos/.*", "http://noembed.com/embed"],
    ["https?://framebuzz\\.com/v/.*", "http://noembed.com/embed"],
    [
        "https?://fiso\\.foxsports\\.com\\.au/isomorphic-widget/.*",
        "http://noembed.com/embed",
    ],
    ["https?://flic\\.kr/p/.*", "http://noembed.com/embed"],
    ["https?://.*\\.flickr\\.com/photos/.*", "http://noembed.com/embed"],
    ["https?://.*\\.flat\\.io/score/.*", "http://noembed.com/embed"],
    ["https?://flat\\.io/score/.*", "http://noembed.com/embed"],
    ["https?://www\\.facebook\\.com/video\\.php", "http://noembed.com/embed"],
    ["https?://www\\.facebook\\.com/.*/videos/.*", "http://noembed.com/embed"],
    ["https?://eyrie\\.io/sparkfun/.*", "http://noembed.com/embed"],
    ["https?://eyrie\\.io/board/.*", "http://noembed.com/embed"],
    ["https?://embedarticles\\.com/.*", "http://noembed.com/embed"],
    ["https?://egliseinfo\\.catholique\\.fr/.*", "http://noembed.com/embed"],
    ["https?://edocr\\.com/docs/.*", "http://noembed.com/embed"],
    ["https?://dotsub\\.com/view/.*", "http://noembed.com/embed"],
    ["https?://www\\.docs\\.com/.*", "http://noembed.com/embed"],
    ["https?://docs\\.com/.*", "http://noembed.com/embed"],
    ["https?://docdro\\.id/.*", "http://noembed.com/embed"],
    ["https?://.*\\.docdroid\\.net/.*", "http://noembed.com/embed"],
    ["https?://www\\.dipity\\.com/.*/.*/", "http://noembed.com/embed"],
    ["https?://.*\\.didacte\\.com/a/course/.*", "http://noembed.com/embed"],
    ["https?://sta\\.sh/.*", "http://noembed.com/embed"],
    ["https?://fav\\.me/.*", "http://noembed.com/embed"],
    ["https?://.*\\.deviantart\\.com/.*#/d.*", "http://noembed.com/embed"],
    ["https?://.*\\.deviantart\\.com/art/.*", "http://noembed.com/embed"],
    ["https?://www\\.dailymotion\\.com/video/.*", "http://noembed.com/embed"],
    ["https?://www\\.dailymile\\.com/people/.*/entries/.*", "http://noembed.com/embed"],
    ["https?://app\\.cyranosystems\\.com/msg/.*", "http://noembed.com/embed"],
    ["https?://staging\\.cyranosystems\\.com/msg/.*", "http://noembed.com/embed"],
    ["https?://crowdranking\\.com/.*/.*", "http://noembed.com/embed"],
    ["https?://coub\\.com/embed/.*", "http://noembed.com/embed"],
    ["https?://coub\\.com/view/.*", "http://noembed.com/embed"],
    ["https?://commaful\\.com/play/.*", "http://noembed.com/embed"],
    ["https?://www\\.collegehumor\\.com/video/.*", "http://noembed.com/embed"],
    ["https?://codesandbox\\.io/embed/.*", "http://noembed.com/embed"],
    ["https?://codesandbox\\.io/s/.*", "http://noembed.com/embed"],
    ["https?://www\\.codepoints\\.net/.*", "http://noembed.com/embed"],
    ["https?://codepoints\\.net/.*", "http://noembed.com/embed"],
    ["https?://codepen\\.io/.*", "http://noembed.com/embed"],
    ["https?://clyp\\.it/playlist/.*", "http://noembed.com/embed"],
    ["https?://clyp\\.it/.*", "http://noembed.com/embed"],
    ["https?://www\\.clipland\\.com/v/.*", "http://noembed.com/embed"],
    ["https?://www\\.circuitlab\\.com/circuit/.*", "http://noembed.com/embed"],
    ["https?://chirb\\.it/.*", "http://noembed.com/embed"],
    ["https?://public\\.chartblocks\\.com/c/.*", "http://noembed.com/embed"],
    ["https?://img\\.catbo\\.at/.*", "http://noembed.com/embed"],
    ["https?://carbonhealth\\.com/practice/.*", "http://noembed.com/embed"],
    ["https?://cacoo\\.com/diagrams/.*", "http://noembed.com/embed"],
    ["https?://buttondown\\.email/.*", "http://noembed.com/embed"],
    ["https?://blackfire\\.io/profiles/compare/.*/graph", "http://noembed.com/embed"],
    ["https?://blackfire\\.io/profiles/.*/graph", "http://noembed.com/embed"],
    ["https?://audiosnaps\\.com/k/.*", "http://noembed.com/embed"],
    ["https?://www\\.audiomack\\.com/playlist/.*", "http://noembed.com/embed"],
    ["https?://www\\.audiomack\\.com/album/.*", "http://noembed.com/embed"],
    ["https?://www\\.audiomack\\.com/song/.*", "http://noembed.com/embed"],
    ["https?://animoto\\.com/play/.*", "http://noembed.com/embed"],
    ["https?://animatron\\.com/project/.*", "http://noembed.com/embed"],
    ["https?://www\\.animatron\\.com/project/.*", "http://noembed.com/embed"],
    ["https?://live\\.amcharts\\.com/.*", "http://noembed.com/embed"],
    ["https?://photos\\.app\\.net/.*/.*", "http://noembed.com/embed"],
    ["https?://alpha\\.app\\.net/.*/post/.*", "http://noembed.com/embed"],
    ["https?://www\\.23hq\\.com/.*/photo/.*", "http://noembed.com/embed"],
    ["https?://news.vice\\.com/[^/]+/?", "http://noembed.com/embed"],
    ["http://www\\.theonion\\.com/articles?/[^/]+/?", "http://noembed.com/embed"],
    ["http://arstechnica\\.com/[^/]+/\\d+/\\d+/[^/]+/?$", "http://noembed.com/embed"],
    ["http://tl\\.gd/[^/]+", "http://noembed.com/embed"],
    ["http://www\\.twitlonger\\.com/show/[a-zA-Z0-9]+", "http://noembed.com/embed"],
    ["http://(?:www\\.)?twitpic\\.com/([^/]+)", "http://noembed.com/embed"],
    ["http://picplz\\.com/user/[^/]+/pic/[^/]+", "http://noembed.com/embed"],
    ["http://gfycat\\.com/([a-zA-Z]+)", "http://noembed.com/embed"],
    ["http://lockerz\\.com/[sd]/\\d+", "http://noembed.com/embed"],
    ["http://skit.ch/[^/]+", "http://noembed.com/embed"],
    ["https?://(?:www.)?skitch.com/([^/]+)/[^/]+/.+", "http://noembed.com/embed"],
    ["https?://(?:www\\.)?xkcd\\.com/\\d+/?", "http://noembed.com/embed"],
    ["http://qik\\.com/video/.*", "http://noembed.com/embed"],
    ["https?://(?:www\\.)?vice\\.com/[^/]+/?", "http://noembed.com/embed"],
    [
        "https?://(?:www\\.)?wired\\.com/([^/]+/)?\\d+/\\d+/[^/]+/?$",
        "http://noembed.com/embed",
    ],
    [
        "http://www\\.duffelblog\\.com/\\d{4}/\\d{1,2}/[^/]+/?$",
        "http://noembed.com/embed",
    ],
    ["http://www.traileraddict.com/trailer/[^/]+/trailer", "http://noembed.com/embed"],
    [
        "http://(?:www\\.)?theverge\\.com/\\d{4}/\\d{1,2}/\\d{1,2}/\\d+/[^/]+/?$",
        "http://noembed.com/embed",
    ],
    [
        "http://www\\.monoprice\\.com/products/product\\.asp\\?.*p_id=\\d+",
        "http://noembed.com/embed",
    ],
    ["http://www\\.asciiartfarts\\.com/[0-9]+\\.html", "http://noembed.com/embed"],
    ["http://trailers\\.apple\\.com/trailers/[^/]+/[^/]+", "http://noembed.com/embed"],
    ["https?://(?:www\\.)?vimeo\\.com/.+", "http://noembed.com/embed"],
    [
        "http://www\\.urbandictionary\\.com/define\\.php\\?term=.+",
        "http://noembed.com/embed",
    ],
    [
        "https?://(?:www|mobile\\.)?twitter\\.com/(?:#!/)?([^/]+)/status(?:es)?/(\\d+)",
        "http://noembed.com/embed",
    ],
    ["https?://soundcloud.com/.*/.*", "http://noembed.com/embed"],
    ["https?://v\\.nldg\\.me/.+", "http://noembed.com/embed"],
    ["https?://www\\.nooledge\\.com/\\!/Vid/.+", "http://noembed.com/embed"],
    ["https?://(?:www\\.)spreaker\\.com/.+", "http://noembed.com/embed"],
    ["https?://(?:www\\.)?avclub\\.com/article/[^/]+/?$", "http://noembed.com/embed"],
    ["https?://path\\.com/p/([0-9a-zA-Z]+)$", "http://noembed.com/embed"],
    [
        "http://boingboing\\.net/\\d{4}/\\d{2}/\\d{2}/[^/]+\\.html",
        "http://noembed.com/embed",
    ],
    ["http://cl\\.ly/(?:image/)?[0-9a-zA-Z]+/?$", "http://noembed.com/embed"],
    ["http://www\\.clickhole\\.com/[^/]+/[^/]?", "http://noembed.com/embed"],
]



OEMBED_PROVIDER_LIST = [
    [
        "https://(\\S*\\.)?youtu(\\.be/|be\\.com/watch)\\S+",
        "http://www.youtube.com/oembed?scheme=https&",
    ],
    [
        "http://(\\S*\\.)?youtu(\\.be/|be\\.com/watch)\\S+",
        "http://www.youtube.com/oembed",
    ],
    ["https?://wordpress\\.tv/\\S+", "http://wordpress.tv/oembed/"],
    ["http://\\S+\\.wordpress\\.com/\\S+", "http://public-api.wordpress.com/oembed/"],
    ["https://vimeo\\.com/\\S+", "https://vimeo.com/api/oembed.json"],
    ["http://vimeo\\.com/\\S+", "http://vimeo.com/api/oembed.json"],
    [
        "https?://(www\\.)?twitter\\.com/\\S+/status(es)?/\\S+",
        "https://api.twitter.com/1/statuses/oembed.json",
    ],
    ["https?://(?:www\\.)?scribd\\.com/\\S*", "http://www.scribd.com/services/oembed"],
    ["https?://speakerdeck\\.com/\\S*", "https://speakerdeck.com/oembed.json"],
    ["https://\\S*?soundcloud\\.com/\\S+", "http://soundcloud.com/oembed"],
    ["http://\\S*\\.smugmug\\.com/\\S*", "http://api.smugmug.com/services/oembed/"],
    ["https?://slidesha\\.re/\\S*", "http://www.slideshare.net/api/oembed/2"],
    [
        "https?://(?:www\\.)?slideshare\\.net/[^\\/]+/\\S+",
        "http://www.slideshare.net/api/oembed/2",
    ],
    ["https?://(.+\\.)?polldaddy\\.com/\\S*", "http://polldaddy.com/oembed/"],
    [
        "http://www\\.polleverywhere\\.com/(polls|multiple_choice_polls|free_text_polls)/\\S+",
        "http://www.polleverywhere.com/services/oembed/",
    ],
    ["http://gi\\S*\\.photobucket\\.com/groups/\\S+", "http://photobucket.com/oembed"],
    ["http://i\\S*\\.photobucket\\.com/albums/\\S+", "http://photobucket.com/oembed"],
    ["http://moby\\.to/\\S*", "http://api.mobypicture.com/oEmbed"],
    [
        "http://www\\.mobypicture\\.com/user/\\S*?/view/\\S*",
        "http://api.mobypicture.com/oEmbed",
    ],
    [
        "https?://(www\\.)?instagr(\\.am|am\\.com)/p/\\S+",
        "http://api.instagram.com/oembed",
    ],
    ["https?://\\S*imgur\\.com/\\S+", "https://api.imgur.com/oembed"],
    ["http://(?:www\\.)hulu\\.com/watch/\\S+", "http://www.hulu.com/api/oembed.json"],
    ["https?://gist\\.github\\.com/\\S*", "https://github.com/api/oembed"],
    [
        "https?://(?:www\\.)?funnyordie\\.com/videos/\\S+",
        "http://www.funnyordie.com/oembed",
    ],
    ["https?://flic\\.kr/\\S*", "https://www.flickr.com/services/oembed/"],
    ["https?://\\S*?flickr\\.com/\\S+", "https://www.flickr.com/services/oembed/"],
    [
        "https?://(?:www\\.)?dailymotion\\.com/\\S+",
        "http://www.dailymotion.com/services/oembed",
    ],
    [
        "https?://www\\.circuitlab\\.com/circuit/\\S+",
        "https://www.circuitlab.com/circuit/oembed",
    ],
    ["http://chirb\\.it/\\S+", "http://chirb.it/oembed.json"],
    [
        "https://(\\S*\\.)?youtu(\\.be/|be\\.com/watch)\\S+",
        "http://www.youtube.com/oembed?scheme=https&",
    ],
    [
        "http://(\\S*\\.)?youtu(\\.be/|be\\.com/watch)\\S+",
        "http://www.youtube.com/oembed",
    ],
    [
        "https://reports.zoho.com/ZDBDataSheetView.cc\\?OBJID=1432535000000003002&STANDALONE=true&INTERVAL=120&DATATYPESYMBOL=false&REMTOOLBAR=false&SEARCHBOX=true&INCLUDETITLE=true&INCLUDEDESC=true&SHOWHIDEOPT=true",
        "http://api.provider.com/oembed.json",
    ],
    [
        "https://[^\\/\\s\\?&]+?.znipe.tv/[^\\/\\s\\?&]+?",
        "https://api.znipe.tv/v3/oembed/",
    ],
    ["https://youtu.be/[^\\/\\s\\?&]+?", "https://www.youtube.com/oembed"],
    [
        "https://[^\\/\\s\\?&]+?.youtube.com/v/[^\\/\\s\\?&]+?",
        "https://www.youtube.com/oembed",
    ],
    [
        "https://[^\\/\\s\\?&]+?.youtube.com/watch[^\\/\\s\\?&]+?",
        "https://www.youtube.com/oembed",
    ],
    ["http://yfrog.us/[^\\/\\s\\?&]+?", "http://www.yfrog.com/api/oembed"],
    [
        "http://[^\\/\\s\\?&]+?.yfrog.com/[^\\/\\s\\?&]+?",
        "http://www.yfrog.com/api/oembed",
    ],
    ["http://www.yesik.it/[^\\/\\s\\?&]+?", "http://yesik.it/s/oembed"],
    ["http://yesik.it/[^\\/\\s\\?&]+?", "http://yesik.it/s/oembed"],
    [
        "https://[^\\/\\s\\?&]+?.wizer.me/preview/[^\\/\\s\\?&]+?",
        "http://app.wizer.me/api/oembed.json",
    ],
    [
        "http://[^\\/\\s\\?&]+?.wizer.me/preview/[^\\/\\s\\?&]+?",
        "http://app.wizer.me/api/oembed.json",
    ],
    [
        "https://[^\\/\\s\\?&]+?.wizer.me/learn/[^\\/\\s\\?&]+?",
        "http://app.wizer.me/api/oembed.json",
    ],
    [
        "http://[^\\/\\s\\?&]+?.wizer.me/learn/[^\\/\\s\\?&]+?",
        "http://app.wizer.me/api/oembed.json",
    ],
    [
        "https://[^\\/\\s\\?&]+?.wistia.com/medias/[^\\/\\s\\?&]+?",
        "https://fast.wistia.com/oembed.json",
    ],
    [
        "https://fast.wistia.com/embed/playlists/[^\\/\\s\\?&]+?",
        "https://fast.wistia.com/oembed.json",
    ],
    [
        "https://fast.wistia.com/embed/iframe/[^\\/\\s\\?&]+?",
        "https://fast.wistia.com/oembed.json",
    ],
    [
        "https://[^\\/\\s\\?&]+?.wiredrive.com/[^\\/\\s\\?&]+?",
        "http://*.wiredrive.com/present-oembed/",
    ],
    [
        "https://article.voxsnap.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://data.voxsnap.com/oembed",
    ],
    ["https://vlurb.co/video/[^\\/\\s\\?&]+?", "https://vlurb.co/oembed.json"],
    ["http://vlurb.co/video/[^\\/\\s\\?&]+?", "https://vlurb.co/oembed.json"],
    ["https://www.vlive.tv/video/[^\\/\\s\\?&]+?", "https://www.vlive.tv/oembed"],
    ["https://vlipsy.com/[^\\/\\s\\?&]+?", "https://vlipsy.com/oembed"],
    [
        "http://viziosphere.com/3dphoto[^\\/\\s\\?&]+?",
        "http://viziosphere.com/services/oembed/",
    ],
    [
        "https://player.vimeo.com/video/[^\\/\\s\\?&]+?",
        "https://vimeo.com/api/oembed.json",
    ],
    [
        "https://vimeo.com/ondemand/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://vimeo.com/api/oembed.json",
    ],
    [
        "https://vimeo.com/groups/[^\\/\\s\\?&]+?/videos/[^\\/\\s\\?&]+?",
        "https://vimeo.com/api/oembed.json",
    ],
    [
        "https://vimeo.com/channels/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://vimeo.com/api/oembed.json",
    ],
    [
        "https://vimeo.com/album/[^\\/\\s\\?&]+?/video/[^\\/\\s\\?&]+?",
        "https://vimeo.com/api/oembed.json",
    ],
    ["https://vimeo.com/[^\\/\\s\\?&]+?", "https://vimeo.com/api/oembed.json"],
    [
        "http://[^\\/\\s\\?&]+?.hubs.vidyard.com/[^\\/\\s\\?&]+?",
        "https://api.vidyard.com/dashboard/v1.1/oembed",
    ],
    [
        "http://share.vidyard.com/[^\\/\\s\\?&]+?",
        "https://api.vidyard.com/dashboard/v1.1/oembed",
    ],
    [
        "http://play.vidyard.com/[^\\/\\s\\?&]+?",
        "https://api.vidyard.com/dashboard/v1.1/oembed",
    ],
    [
        "http://embed.vidyard.com/[^\\/\\s\\?&]+?",
        "https://api.vidyard.com/dashboard/v1.1/oembed",
    ],
    [
        "https://players.vidmizer.com/[^\\/\\s\\?&]+?",
        "https://app-v2.vidmizer.com/api/oembed",
    ],
    ["https://vidl.it/[^\\/\\s\\?&]+?", "https://api.vidl.it/oembed"],
    [
        "http://www.videojug.com/interview/[^\\/\\s\\?&]+?",
        "http://www.videojug.com/oembed.json",
    ],
    [
        "http://www.videojug.com/film/[^\\/\\s\\?&]+?",
        "http://www.videojug.com/oembed.json",
    ],
    ["https://www.vevo.com/[^\\/\\s\\?&]+?", "https://www.vevo.com/oembed"],
    ["http://www.vevo.com/[^\\/\\s\\?&]+?", "https://www.vevo.com/oembed"],
    ["http://veervr.tv/videos/[^\\/\\s\\?&]+?", "https://api.veervr.tv/oembed"],
    ["http://veer.tv/videos/[^\\/\\s\\?&]+?", "https://api.veer.tv/oembed"],
    ["http://uttles.com/uttle/[^\\/\\s\\?&]+?", "http://uttles.com/api/reply/oembed"],
    [
        "http://utposts.com/products/[^\\/\\s\\?&]+?",
        "https://www.utposts.com/api/oembed",
    ],
    [
        "https://utposts.com/products/[^\\/\\s\\?&]+?",
        "https://www.utposts.com/api/oembed",
    ],
    [
        "http://www.utposts.com/products/[^\\/\\s\\?&]+?",
        "https://www.utposts.com/api/oembed",
    ],
    [
        "https://www.utposts.com/products/[^\\/\\s\\?&]+?",
        "https://www.utposts.com/api/oembed",
    ],
    [
        "http://[^\\/\\s\\?&]+?.ustream.com/[^\\/\\s\\?&]+?",
        "http://www.ustream.tv/oembed",
    ],
    [
        "http://[^\\/\\s\\?&]+?.ustream.tv/[^\\/\\s\\?&]+?",
        "http://www.ustream.tv/oembed",
    ],
    [
        "https://[^\\/\\s\\?&]+?.uol.com.br/video/[^\\/\\s\\?&]+?",
        "https://mais.uol.com.br/apiuol/v3/oembed/view",
    ],
    [
        "https://[^\\/\\s\\?&]+?.uol.com.br/view/[^\\/\\s\\?&]+?",
        "https://mais.uol.com.br/apiuol/v3/oembed/view",
    ],
    ["https://map.cam.ac.uk/[^\\/\\s\\?&]+?", "https://map.cam.ac.uk/oembed/"],
    [
        "https://player.ubideo.com/[^\\/\\s\\?&]+?",
        "https://player.ubideo.com/api/oembed.json",
    ],
    ["https://play.typecast.ai/[^\\/\\s\\?&]+?", "https://play.typecast.ai/oembed"],
    ["https://play.typecast.ai/e/[^\\/\\s\\?&]+?", "https://play.typecast.ai/oembed"],
    ["https://play.typecast.ai/s/[^\\/\\s\\?&]+?", "https://play.typecast.ai/oembed"],
    [
        "https://[^\\/\\s\\?&]+?.twitter.com/[^\\/\\s\\?&]+?/status/[^\\/\\s\\?&]+?",
        "https://publish.twitter.com/oembed",
    ],
    [
        "https://twitter.com/[^\\/\\s\\?&]+?/status/[^\\/\\s\\?&]+?",
        "https://publish.twitter.com/oembed",
    ],
    ["https://twitch.tv/[^\\/\\s\\?&]+?", "https://api.twitch.tv/v4/oembed"],
    ["http://twitch.tv/[^\\/\\s\\?&]+?", "https://api.twitch.tv/v4/oembed"],
    ["https://www.twitch.tv/[^\\/\\s\\?&]+?", "https://api.twitch.tv/v4/oembed"],
    ["http://www.twitch.tv/[^\\/\\s\\?&]+?", "https://api.twitch.tv/v4/oembed"],
    ["https://clips.twitch.tv/[^\\/\\s\\?&]+?", "https://api.twitch.tv/v4/oembed"],
    ["http://clips.twitch.tv/[^\\/\\s\\?&]+?", "https://api.twitch.tv/v4/oembed"],
    [
        "http://www.tvcf.co.kr/v/[^\\/\\s\\?&]+?",
        "http://www.tvcf.co.kr/services/oembed",
    ],
    ["https://www.tuxx.be/[^\\/\\s\\?&]+?", "https://www.tuxx.be/services/oembed"],
    ["http://www.topy.se/image/[^\\/\\s\\?&]+?", "http://www.topy.se/oembed/"],
    [
        "https://www.toornament.com/tournaments/[^\\/\\s\\?&]+?/stages/[^\\/\\s\\?&]+?/",
        "https://widget.toornament.com/oembed",
    ],
    [
        "https://www.toornament.com/tournaments/[^\\/\\s\\?&]+?/matches/schedule",
        "https://widget.toornament.com/oembed",
    ],
    [
        "https://www.toornament.com/tournaments/[^\\/\\s\\?&]+?/registration/",
        "https://widget.toornament.com/oembed",
    ],
    [
        "https://www.toornament.com/tournaments/[^\\/\\s\\?&]+?/information",
        "https://widget.toornament.com/oembed",
    ],
    [
        "https://www.tickcounter.com/worldclock/[^\\/\\s\\?&]+?",
        "https://www.tickcounter.com/oembed",
    ],
    [
        "https://www.tickcounter.com/ticker/[^\\/\\s\\?&]+?",
        "https://www.tickcounter.com/oembed",
    ],
    [
        "https://www.tickcounter.com/countup/[^\\/\\s\\?&]+?",
        "https://www.tickcounter.com/oembed",
    ],
    [
        "https://www.tickcounter.com/countdown/[^\\/\\s\\?&]+?",
        "https://www.tickcounter.com/oembed",
    ],
    [
        "http://www.tickcounter.com/worldclock/[^\\/\\s\\?&]+?",
        "https://www.tickcounter.com/oembed",
    ],
    [
        "http://www.tickcounter.com/ticker/[^\\/\\s\\?&]+?",
        "https://www.tickcounter.com/oembed",
    ],
    [
        "http://www.tickcounter.com/countup/[^\\/\\s\\?&]+?",
        "https://www.tickcounter.com/oembed",
    ],
    [
        "http://www.tickcounter.com/countdown/[^\\/\\s\\?&]+?",
        "https://www.tickcounter.com/oembed",
    ],
    [
        "https://theysaidso.com/image/[^\\/\\s\\?&]+?",
        "https://theysaidso.com/extensions/oembed/",
    ],
    [
        "https://[^\\/\\s\\?&]+?.nytimes.com/[^\\/\\s\\?&]+?",
        "https://www.nytimes.com/svc/oembed/json/",
    ],
    ["https://nytimes.com/[^\\/\\s\\?&]+?", "https://www.nytimes.com/svc/oembed/json/"],
    ["https://www.nytimes.com/svc/oembed", "https://www.nytimes.com/svc/oembed/json/"],
    [
        "https://www.ted.com/talks/[^\\/\\s\\?&]+?",
        "https://www.ted.com/talks/oembed.json",
    ],
    ["https://ted.com/talks/[^\\/\\s\\?&]+?", "https://www.ted.com/talks/oembed.json"],
    ["http://ted.com/talks/[^\\/\\s\\?&]+?", "https://www.ted.com/talks/oembed.json"],
    ["https://www.sway.com/[^\\/\\s\\?&]+?", "https://sway.com/api/v1.0/oembed"],
    ["https://sway.com/[^\\/\\s\\?&]+?", "https://sway.com/api/v1.0/oembed"],
    [
        "https://www.sutori.com/story/[^\\/\\s\\?&]+?",
        "https://www.sutori.com/api/oembed",
    ],
    [
        "https://content.streamonecloud.net/embed/[^\\/\\s\\?&]+?",
        "https://content.streamonecloud.net/oembed",
    ],
    [
        "https://streamable.com/[^\\/\\s\\?&]+?",
        "https://api.streamable.com/oembed.json",
    ],
    ["http://streamable.com/[^\\/\\s\\?&]+?", "https://api.streamable.com/oembed.json"],
    [
        "https://purl.stanford.edu/[^\\/\\s\\?&]+?",
        "https://purl.stanford.edu/embed.json",
    ],
    [
        "https://[^\\/\\s\\?&]+?.spreaker.com/[^\\/\\s\\?&]+?",
        "https://api.spreaker.com/oembed",
    ],
    [
        "http://[^\\/\\s\\?&]+?.spreaker.com/[^\\/\\s\\?&]+?",
        "https://api.spreaker.com/oembed",
    ],
    ["spotify:[^\\/\\s\\?&]+?", "https://embed.spotify.com/oembed/"],
    [
        "https://[^\\/\\s\\?&]+?.spotify.com/[^\\/\\s\\?&]+?",
        "https://embed.spotify.com/oembed/",
    ],
    ["http://play.bespotful.com/[^\\/\\s\\?&]+?", "https://api.bespotful.com/oembed"],
    [
        "https://speakerdeck.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://speakerdeck.com/oembed.json",
    ],
    [
        "http://speakerdeck.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://speakerdeck.com/oembed.json",
    ],
    [
        "https://soundsgood.co/playlist/[^\\/\\s\\?&]+?",
        "https://play.soundsgood.co/oembed",
    ],
    [
        "https://play.soundsgood.co/playlist/[^\\/\\s\\?&]+?",
        "https://play.soundsgood.co/oembed",
    ],
    ["https://soundcloud.com/[^\\/\\s\\?&]+?", "https://soundcloud.com/oembed"],
    ["http://soundcloud.com/[^\\/\\s\\?&]+?", "https://soundcloud.com/oembed"],
    ["https://song.link/[^\\/\\s\\?&]+?", "https://song.link/oembed"],
    [
        "https://www.socialexplorer.com/[^\\/\\s\\?&]+?/embed",
        "https://www.socialexplorer.com/services/oembed/",
    ],
    [
        "https://www.socialexplorer.com/[^\\/\\s\\?&]+?/edit",
        "https://www.socialexplorer.com/services/oembed/",
    ],
    [
        "https://www.socialexplorer.com/[^\\/\\s\\?&]+?/view",
        "https://www.socialexplorer.com/services/oembed/",
    ],
    [
        "https://www.socialexplorer.com/[^\\/\\s\\?&]+?/explore",
        "https://www.socialexplorer.com/services/oembed/",
    ],
    [
        "http://[^\\/\\s\\?&]+?.smugmug.com/[^\\/\\s\\?&]+?",
        "http://api.smugmug.com/services/oembed/",
    ],
    [
        "https://smashnotes.com/p/[^\\/\\s\\?&]+?/e/[^\\/\\s\\?&]+? - https://smashnotes.com/p/[^\\/\\s\\?&]+?/e/[^\\/\\s\\?&]+?/s/[^\\/\\s\\?&]+?",
        "https://smashnotes.com/services/oembed",
    ],
    [
        "https://smashnotes.com/p/[^\\/\\s\\?&]+?",
        "https://smashnotes.com/services/oembed",
    ],
    [
        "http://pt.slideshare.net/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "http://www.slideshare.net/api/oembed/2",
    ],
    [
        "http://es.slideshare.net/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "http://www.slideshare.net/api/oembed/2",
    ],
    [
        "http://de.slideshare.net/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "http://www.slideshare.net/api/oembed/2",
    ],
    [
        "http://fr.slideshare.net/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "http://www.slideshare.net/api/oembed/2",
    ],
    [
        "http://www.slideshare.net/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "http://www.slideshare.net/api/oembed/2",
    ],
    [
        "https://sketchfab.com/[^\\/\\s\\?&]+?/folders/[^\\/\\s\\?&]+?",
        "http://sketchfab.com/oembed",
    ],
    ["https://sketchfab.com/models/[^\\/\\s\\?&]+?", "http://sketchfab.com/oembed"],
    ["http://sketchfab.com/models/[^\\/\\s\\?&]+?", "http://sketchfab.com/oembed"],
    ["https://onsizzle.com/i/[^\\/\\s\\?&]+?", "https://onsizzle.com/oembed"],
    ["https://simplecast.com/s/[^\\/\\s\\?&]+?", "https://simplecast.com/oembed"],
    ["https://showtheway.io/to/[^\\/\\s\\?&]+?", "https://showtheway.io/oembed"],
    ["http://shoud.io/[^\\/\\s\\?&]+?", "http://shoudio.com/api/oembed"],
    ["http://shoudio.com/[^\\/\\s\\?&]+?", "http://shoudio.com/api/oembed"],
    [
        "https://www.shortnote.jp/view/notes/[^\\/\\s\\?&]+?",
        "https://www.shortnote.jp/oembed/",
    ],
    [
        "https://embed.sendtonews.com/oembed/[^\\/\\s\\?&]+?",
        "https://embed.sendtonews.com/services/oembed",
    ],
    [
        "http://www.scribd.com/doc/[^\\/\\s\\?&]+?",
        "http://www.scribd.com/services/oembed/",
    ],
    [
        "https://scribblemaps.com/maps/view/[^\\/\\s\\?&]+?",
        "https://scribblemaps.com/api/services/oembed.json",
    ],
    [
        "http://scribblemaps.com/maps/view/[^\\/\\s\\?&]+?",
        "https://scribblemaps.com/api/services/oembed.json",
    ],
    [
        "https://www.scribblemaps.com/maps/view/[^\\/\\s\\?&]+?",
        "https://scribblemaps.com/api/services/oembed.json",
    ],
    [
        "http://www.scribblemaps.com/maps/view/[^\\/\\s\\?&]+?",
        "https://scribblemaps.com/api/services/oembed.json",
    ],
    [
        "http://www.screenr.com/[^\\/\\s\\?&]+?/",
        "http://www.screenr.com/api/oembed.json",
    ],
    [
        "https://[^\\/\\s\\?&]+?.screen9.tv/[^\\/\\s\\?&]+?",
        "https://api.screen9.com/oembed",
    ],
    ["https://console.screen9.com/[^\\/\\s\\?&]+?", "https://api.screen9.com/oembed"],
    ["http://videos.sapo.pt/[^\\/\\s\\?&]+?", "http://videos.sapo.pt/oembed"],
    ["https://roosterteeth.com/[^\\/\\s\\?&]+?", "https://roosterteeth.com/oembed"],
    [
        "http://roomshare.jp/en/post/[^\\/\\s\\?&]+?",
        "http://roomshare.jp/en/oembed.json",
    ],
    ["http://roomshare.jp/post/[^\\/\\s\\?&]+?", "http://roomshare.jp/en/oembed.json"],
    [
        "https://www.reverbnation.com/[^\\/\\s\\?&]+?/songs/[^\\/\\s\\?&]+?",
        "https://www.reverbnation.com/oembed",
    ],
    [
        "https://www.reverbnation.com/[^\\/\\s\\?&]+?",
        "https://www.reverbnation.com/oembed",
    ],
    [
        "http://repubhub.icopyright.net/freePost.act\\?[^\\/\\s\\?&]+?",
        "http://repubhub.icopyright.net/oembed.act",
    ],
    ["https://repl.it/@[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?", "https://repl.it/data/oembed"],
    ["http://rwire.com/[^\\/\\s\\?&]+?", "http://publisher.releasewire.com/oembed/"],
    [
        "https://www.reddit.com/r/[^\\/\\s\\?&]+?/comments/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://www.reddit.com/oembed",
    ],
    [
        "https://reddit.com/r/[^\\/\\s\\?&]+?/comments/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://www.reddit.com/oembed",
    ],
    ["https://rapidengage.com/s/[^\\/\\s\\?&]+?", "https://rapidengage.com/api/oembed"],
    [
        "http://www.quizz.biz/quizz-[^\\/\\s\\?&]+?.html",
        "http://www.quizz.biz/api/oembed",
    ],
    [
        "http://www.quiz.biz/quizz-[^\\/\\s\\?&]+?.html",
        "http://www.quiz.biz/api/oembed",
    ],
    [
        "https://posixion.com/[^\\/\\s\\?&]+?/question/[^\\/\\s\\?&]+?",
        "http://posixion.com/services/oembed/",
    ],
    [
        "https://posixion.com/question/[^\\/\\s\\?&]+?",
        "http://posixion.com/services/oembed/",
    ],
    [
        "https://portfolium.com/entry/[^\\/\\s\\?&]+?",
        "https://api.portfolium.com/oembed",
    ],
    [
        "https://app.sellwithport.com/#/buyer/[^\\/\\s\\?&]+?",
        "https://api.sellwithport.com/v1.0/buyer/oembed",
    ],
    [
        "http://[^\\/\\s\\?&]+?.polldaddy.com/ratings/[^\\/\\s\\?&]+?",
        "http://polldaddy.com/oembed/",
    ],
    [
        "http://[^\\/\\s\\?&]+?.polldaddy.com/poll/[^\\/\\s\\?&]+?",
        "http://polldaddy.com/oembed/",
    ],
    [
        "http://[^\\/\\s\\?&]+?.polldaddy.com/s/[^\\/\\s\\?&]+?",
        "http://polldaddy.com/oembed/",
    ],
    [
        "http://[^\\/\\s\\?&]+?.podbean.com/e/[^\\/\\s\\?&]+?",
        "https://api.podbean.com/v1/oembed",
    ],
    [
        "https://[^\\/\\s\\?&]+?.podbean.com/e/[^\\/\\s\\?&]+?",
        "https://api.podbean.com/v1/oembed",
    ],
    [
        "https://store.pixdor.com/map/[^\\/\\s\\?&]+?/show",
        "https://store.pixdor.com/oembed",
    ],
    [
        "https://store.pixdor.com/place-marker-widget/[^\\/\\s\\?&]+?/show",
        "https://store.pixdor.com/oembed",
    ],
    ["https://www.pastery.net/[^\\/\\s\\?&]+?", "https://www.pastery.net/oembed"],
    ["http://www.pastery.net/[^\\/\\s\\?&]+?", "https://www.pastery.net/oembed"],
    ["https://pastery.net/[^\\/\\s\\?&]+?", "https://www.pastery.net/oembed"],
    ["http://pastery.net/[^\\/\\s\\?&]+?", "https://www.pastery.net/oembed"],
    [
        "https://overflow.io/embed/[^\\/\\s\\?&]+?",
        "https://overflow.io/services/oembed",
    ],
    ["https://overflow.io/s/[^\\/\\s\\?&]+?", "https://overflow.io/services/oembed"],
    ["https://outplayed.tv/media/[^\\/\\s\\?&]+?", "https://outplayed.tv/oembed"],
    ["https://www.oumy.com/v/[^\\/\\s\\?&]+?", "https://www.oumy.com/oembed"],
    [
        "http://orbitvu.co/001/[^\\/\\s\\?&]+?/1/2/orbittour/[^\\/\\s\\?&]+?/view",
        "http://orbitvu.co/service/oembed",
    ],
    [
        "http://orbitvu.co/001/[^\\/\\s\\?&]+?/2/orbittour/[^\\/\\s\\?&]+?/view",
        "http://orbitvu.co/service/oembed",
    ],
    [
        "http://orbitvu.co/001/[^\\/\\s\\?&]+?/ov3602/[^\\/\\s\\?&]+?/view",
        "http://orbitvu.co/service/oembed",
    ],
    [
        "http://orbitvu.co/001/[^\\/\\s\\?&]+?/ov3601/[^\\/\\s\\?&]+?/view",
        "http://orbitvu.co/service/oembed",
    ],
    [
        "http://orbitvu.co/001/[^\\/\\s\\?&]+?/ov3601/view",
        "http://orbitvu.co/service/oembed",
    ],
    [
        "https://orbitvu.co/001/[^\\/\\s\\?&]+?/1/2/orbittour/[^\\/\\s\\?&]+?/view",
        "http://orbitvu.co/service/oembed",
    ],
    [
        "https://orbitvu.co/001/[^\\/\\s\\?&]+?/2/orbittour/[^\\/\\s\\?&]+?/view",
        "http://orbitvu.co/service/oembed",
    ],
    [
        "https://orbitvu.co/001/[^\\/\\s\\?&]+?/ov3602/[^\\/\\s\\?&]+?/view",
        "http://orbitvu.co/service/oembed",
    ],
    [
        "https://orbitvu.co/001/[^\\/\\s\\?&]+?/ov3601/[^\\/\\s\\?&]+?/view",
        "http://orbitvu.co/service/oembed",
    ],
    [
        "https://orbitvu.co/001/[^\\/\\s\\?&]+?/ov3601/view",
        "http://orbitvu.co/service/oembed",
    ],
    ["http://on.aol.com/video/[^\\/\\s\\?&]+?", "http://on.aol.com/api"],
    [
        "https://omniscope.me/[^\\/\\s\\?&]+?",
        "https://omniscope.me/_global_/oembed/json",
    ],
    [
        "http://official.fm/playlists/[^\\/\\s\\?&]+?",
        "http://official.fm/services/oembed.json",
    ],
    [
        "http://official.fm/tracks/[^\\/\\s\\?&]+?",
        "http://official.fm/services/oembed.json",
    ],
    ["https://odds.com.au/[^\\/\\s\\?&]+?", "https://www.odds.com.au/api/oembed/"],
    ["https://www.odds.com.au/[^\\/\\s\\?&]+?", "https://www.odds.com.au/api/oembed/"],
    [
        "http://[^\\/\\s\\?&]+?.nfb.ca/film/[^\\/\\s\\?&]+?",
        "http://www.nfb.ca/remote/services/oembed/",
    ],
    [
        "https://naturalatlas.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://naturalatlas.com/oembed.json",
    ],
    [
        "https://naturalatlas.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://naturalatlas.com/oembed.json",
    ],
    [
        "https://naturalatlas.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://naturalatlas.com/oembed.json",
    ],
    [
        "https://naturalatlas.com/[^\\/\\s\\?&]+?",
        "https://naturalatlas.com/oembed.json",
    ],
    ["https://www.nb.no/items/[^\\/\\s\\?&]+?", "https://api.nb.no/catalog/v1/oembed"],
    [
        "https://new.media.zhdk.ch/signatur/[^\\/\\s\\?&]+?",
        "https://www.nanoo.tv/services/oembed",
    ],
    [
        "https://media.zhdk.ch/signatur/[^\\/\\s\\?&]+?",
        "https://www.nanoo.tv/services/oembed",
    ],
    [
        "http://new.media.zhdk.ch/signatur/[^\\/\\s\\?&]+?",
        "https://www.nanoo.tv/services/oembed",
    ],
    [
        "http://media.zhdk.ch/signatur/[^\\/\\s\\?&]+?",
        "https://www.nanoo.tv/services/oembed",
    ],
    ["https://nanoo.pro/link/[^\\/\\s\\?&]+?", "https://www.nanoo.tv/services/oembed"],
    [
        "https://[^\\/\\s\\?&]+?.nanoo.pro/link/[^\\/\\s\\?&]+?",
        "https://www.nanoo.tv/services/oembed",
    ],
    ["https://nanoo.tv/link/[^\\/\\s\\?&]+?", "https://www.nanoo.tv/services/oembed"],
    [
        "https://[^\\/\\s\\?&]+?.nanoo.tv/link/[^\\/\\s\\?&]+?",
        "https://www.nanoo.tv/services/oembed",
    ],
    ["http://nanoo.pro/link/[^\\/\\s\\?&]+?", "https://www.nanoo.tv/services/oembed"],
    [
        "http://[^\\/\\s\\?&]+?.nanoo.pro/link/[^\\/\\s\\?&]+?",
        "https://www.nanoo.tv/services/oembed",
    ],
    ["http://nanoo.tv/link/[^\\/\\s\\?&]+?", "https://www.nanoo.tv/services/oembed"],
    [
        "http://[^\\/\\s\\?&]+?.nanoo.tv/link/[^\\/\\s\\?&]+?",
        "https://www.nanoo.tv/services/oembed",
    ],
    ["https://namchey.com/embeds/[^\\/\\s\\?&]+?", "https://namchey.com/api/oembed"],
    ["https://mybeweeg.com/w/[^\\/\\s\\?&]+?", "https://mybeweeg.com/services/oembed"],
    [
        "https://musicboxmaniacs.com/explore/melody/[^\\/\\s\\?&]+?",
        "https://musicboxmaniacs.com/embed/",
    ],
    [
        "https://m-roll.morphcast.com/mroll/[^\\/\\s\\?&]+?",
        "https://m-roll.morphcast.com/service/oembed",
    ],
    [
        "https://beta.modelo.io/embedded/[^\\/\\s\\?&]+?",
        "https://portal.modelo.io/oembed",
    ],
    ["http://moby.to/[^\\/\\s\\?&]+?", "http://api.mobypicture.com/oEmbed"],
    [
        "http://www.mobypicture.com/user/[^\\/\\s\\?&]+?/view/[^\\/\\s\\?&]+?",
        "http://api.mobypicture.com/oEmbed",
    ],
    [
        "https://www.mixcloud.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?/",
        "https://www.mixcloud.com/oembed/",
    ],
    [
        "http://www.mixcloud.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?/",
        "https://www.mixcloud.com/oembed/",
    ],
    ["http://meetu.ps/[^\\/\\s\\?&]+?", "https://api.meetup.com/oembed"],
    ["https://meetup.com/[^\\/\\s\\?&]+?", "https://api.meetup.com/oembed"],
    ["https://www.meetup.com/[^\\/\\s\\?&]+?", "https://api.meetup.com/oembed"],
    ["http://meetup.com/[^\\/\\s\\?&]+?", "https://api.meetup.com/oembed"],
    [
        "https://medienarchiv.zhdk.ch/entries/[^\\/\\s\\?&]+?",
        "https://medienarchiv.zhdk.ch/oembed.json",
    ],
    ["https://me.me/i/[^\\/\\s\\?&]+?", "https://me.me/oembed"],
    [
        "http://mathembed.com/latex\\?inputText=[^\\/\\s\\?&]+?",
        "http://mathembed.com/oembed",
    ],
    ["https://app.ludus.one/[^\\/\\s\\?&]+?", "https://app.ludus.one/oembed"],
    [
        "https://livestream.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?/videos/[^\\/\\s\\?&]+?",
        "https://livestream.com/oembed",
    ],
    [
        "https://livestream.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://livestream.com/oembed",
    ],
    [
        "https://livestream.com/[^\\/\\s\\?&]+?/events/[^\\/\\s\\?&]+?/videos/[^\\/\\s\\?&]+?",
        "https://livestream.com/oembed",
    ],
    [
        "https://livestream.com/[^\\/\\s\\?&]+?/events/[^\\/\\s\\?&]+?",
        "https://livestream.com/oembed",
    ],
    [
        "https://livestream.com/accounts/[^\\/\\s\\?&]+?/events/[^\\/\\s\\?&]+?/videos/[^\\/\\s\\?&]+?",
        "https://livestream.com/oembed",
    ],
    [
        "https://livestream.com/accounts/[^\\/\\s\\?&]+?/events/[^\\/\\s\\?&]+?",
        "https://livestream.com/oembed",
    ],
    [
        "https://pod.univ-lille.fr/video/[^\\/\\s\\?&]+?",
        "https://pod.univ-lille.fr/oembed",
    ],
    ["http://learningapps.org/[^\\/\\s\\?&]+?", "http://learningapps.org/oembed.php"],
    ["https://jdr.knacki.info/meuh/[^\\/\\s\\?&]+?", "https://jdr.knacki.info/oembed"],
    ["http://jdr.knacki.info/meuh/[^\\/\\s\\?&]+?", "https://jdr.knacki.info/oembed"],
    [
        "http://www.kitchenbowl.com/recipe/[^\\/\\s\\?&]+?",
        "http://www.kitchenbowl.com/oembed",
    ],
    ["https://kit.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?", "https://embed.kit.com/oembed"],
    ["http://kit.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?", "https://embed.kit.com/oembed"],
    [
        "https://www.kidoju.com/fr/x/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://www.kidoju.com/api/oembed",
    ],
    [
        "https://www.kidoju.com/en/x/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://www.kidoju.com/api/oembed",
    ],
    [
        "http://www.kickstarter.com/projects/[^\\/\\s\\?&]+?",
        "http://www.kickstarter.com/services/oembed",
    ],
    ["https://tv.kakao.com/channel/l/[^\\/\\s\\?&]+?", "https://tv.kakao.com/oembed"],
    [
        "https://tv.kakao.com/channel/[^\\/\\s\\?&]+?/livelink/[^\\/\\s\\?&]+?",
        "https://tv.kakao.com/oembed",
    ],
    ["https://tv.kakao.com/channel/v/[^\\/\\s\\?&]+?", "https://tv.kakao.com/oembed"],
    [
        "https://tv.kakao.com/channel/[^\\/\\s\\?&]+?/cliplink/[^\\/\\s\\?&]+?",
        "https://tv.kakao.com/oembed",
    ],
    [
        "https://issuu.com/[^\\/\\s\\?&]+?/docs/[^\\/\\s\\?&]+?",
        "https://issuu.com/oembed",
    ],
    ["https://www.isnare.com/[^\\/\\s\\?&]+?", "https://www.isnare.com/oembed/"],
    ["https://www.instagr.am/p/[^\\/\\s\\?&]+?", "https://api.instagram.com/oembed"],
    ["https://www.instagram.com/p/[^\\/\\s\\?&]+?", "https://api.instagram.com/oembed"],
    ["https://instagr.am/p/[^\\/\\s\\?&]+?", "https://api.instagram.com/oembed"],
    ["https://instagram.com/p/[^\\/\\s\\?&]+?", "https://api.instagram.com/oembed"],
    ["http://www.instagr.am/p/[^\\/\\s\\?&]+?", "https://api.instagram.com/oembed"],
    ["http://www.instagram.com/p/[^\\/\\s\\?&]+?", "https://api.instagram.com/oembed"],
    ["http://instagr.am/p/[^\\/\\s\\?&]+?", "https://api.instagram.com/oembed"],
    ["http://instagram.com/p/[^\\/\\s\\?&]+?", "https://api.instagram.com/oembed"],
    [
        "http://[^\\/\\s\\?&]+?.inphood.com/[^\\/\\s\\?&]+?",
        "http://api.inphood.com/oembed",
    ],
    ["https://www.inoreader.com/oembed/", "https://www.inoreader.com/oembed/api/"],
    [
        "https://www.injurymap.com/exercises/[^\\/\\s\\?&]+?",
        "https://www.injurymap.com/services/oembed",
    ],
    [
        "https://[^\\/\\s\\?&]+?.infoveave.net/P/[^\\/\\s\\?&]+?",
        "https://infoveave.net/services/oembed/",
    ],
    [
        "https://[^\\/\\s\\?&]+?.infoveave.net/E/[^\\/\\s\\?&]+?",
        "https://infoveave.net/services/oembed/",
    ],
    ["https://infogr.am/[^\\/\\s\\?&]+?", "https://infogr.am/oembed"],
    [
        "https://player.indacolive.com/player/jwp/clients/[^\\/\\s\\?&]+?",
        "https://player.indacolive.com/services/oembed",
    ],
    ["http://ifttt.com/recipes/[^\\/\\s\\?&]+?", "http://www.ifttt.com/oembed/"],
    ["http://www.ifixit.com/Guide/View/[^\\/\\s\\?&]+?", "http://www.ifixit.com/Embed"],
    [
        "http://www.hulu.com/watch/[^\\/\\s\\?&]+?",
        "http://www.hulu.com/api/oembed.json",
    ],
    [
        "http://huffduffer.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "http://huffduffer.com/oembed",
    ],
    [
        "https://hearthis.at/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?/",
        "https://hearthis.at/oembed/",
    ],
    ["https://gyazo.com/[^\\/\\s\\?&]+?", "https://api.gyazo.com/api/oembed"],
    ["https://gtchannel.com/watch/[^\\/\\s\\?&]+?", "https://api.luminery.com/oembed"],
    [
        "https://media.giphy.com/media/[^\\/\\s\\?&]+?/giphy.gif",
        "https://giphy.com/services/oembed",
    ],
    ["http://gph.is/[^\\/\\s\\?&]+?", "https://giphy.com/services/oembed"],
    ["https://giphy.com/gifs/[^\\/\\s\\?&]+?", "https://giphy.com/services/oembed"],
    [
        "https://www.gifnote.com/play/[^\\/\\s\\?&]+?",
        "https://www.gifnote.com/services/oembed",
    ],
    ["https://www.gfycat.com/[^\\/\\s\\?&]+?", "https://api.gfycat.com/v1/oembed"],
    ["https://gfycat.com/[^\\/\\s\\?&]+?", "https://api.gfycat.com/v1/oembed"],
    ["http://www.gfycat.com/[^\\/\\s\\?&]+?", "https://api.gfycat.com/v1/oembed"],
    ["http://gfycat.com/[^\\/\\s\\?&]+?", "https://api.gfycat.com/v1/oembed"],
    ["http://gty.im/[^\\/\\s\\?&]+?", "http://embed.gettyimages.com/oembed"],
    [
        "http://germany.geograph.org/[^\\/\\s\\?&]+?",
        "http://geo.hlipp.de/restapi.php/api/oembed",
    ],
    [
        "http://geo.hlipp.de/[^\\/\\s\\?&]+?",
        "http://geo.hlipp.de/restapi.php/api/oembed",
    ],
    [
        "http://geo-en.hlipp.de/[^\\/\\s\\?&]+?",
        "http://geo.hlipp.de/restapi.php/api/oembed",
    ],
    [
        "http://[^\\/\\s\\?&]+?.channel.geographs.org/[^\\/\\s\\?&]+?",
        "http://www.geograph.org.gg/api/oembed",
    ],
    [
        "http://channel-islands.geographs.org/[^\\/\\s\\?&]+?",
        "http://www.geograph.org.gg/api/oembed",
    ],
    [
        "http://channel-islands.geograph.org/[^\\/\\s\\?&]+?",
        "http://www.geograph.org.gg/api/oembed",
    ],
    [
        "http://[^\\/\\s\\?&]+?.geograph.org.je/[^\\/\\s\\?&]+?",
        "http://www.geograph.org.gg/api/oembed",
    ],
    [
        "http://[^\\/\\s\\?&]+?.geograph.org.gg/[^\\/\\s\\?&]+?",
        "http://www.geograph.org.gg/api/oembed",
    ],
    [
        "http://[^\\/\\s\\?&]+?.wikimedia.org/[^\\/\\s\\?&]+?_geograph.org.uk_[^\\/\\s\\?&]+?",
        "http://api.geograph.org.uk/api/oembed",
    ],
    [
        "http://[^\\/\\s\\?&]+?.geograph.ie/[^\\/\\s\\?&]+?",
        "http://api.geograph.org.uk/api/oembed",
    ],
    [
        "http://[^\\/\\s\\?&]+?.geograph.co.uk/[^\\/\\s\\?&]+?",
        "http://api.geograph.org.uk/api/oembed",
    ],
    [
        "http://[^\\/\\s\\?&]+?.geograph.org.uk/[^\\/\\s\\?&]+?",
        "http://api.geograph.org.uk/api/oembed",
    ],
    [
        "http://www.funnyordie.com/videos/[^\\/\\s\\?&]+?",
        "http://www.funnyordie.com/oembed.json",
    ],
    ["https://framebuzz.com/v/[^\\/\\s\\?&]+?", "https://framebuzz.com/oembed/"],
    ["http://framebuzz.com/v/[^\\/\\s\\?&]+?", "https://framebuzz.com/oembed/"],
    [
        "https://fiso.foxsports.com.au/isomorphic-widget/[^\\/\\s\\?&]+?",
        "https://fiso.foxsports.com.au/oembed",
    ],
    [
        "http://fiso.foxsports.com.au/isomorphic-widget/[^\\/\\s\\?&]+?",
        "https://fiso.foxsports.com.au/oembed",
    ],
    ["https://catapult.fontself.com/[^\\/\\s\\?&]+?", "https://oembed.fontself.com/"],
    [
        "https://public.flourish.studio/story/[^\\/\\s\\?&]+?",
        "https://app.flourish.studio/api/v1/oembed",
    ],
    [
        "https://public.flourish.studio/visualisation/[^\\/\\s\\?&]+?",
        "https://app.flourish.studio/api/v1/oembed",
    ],
    ["https://flic.kr/p/[^\\/\\s\\?&]+?", "https://www.flickr.com/services/oembed/"],
    [
        "https://[^\\/\\s\\?&]+?.flickr.com/photos/[^\\/\\s\\?&]+?",
        "https://www.flickr.com/services/oembed/",
    ],
    ["http://flic.kr/p/[^\\/\\s\\?&]+?", "https://www.flickr.com/services/oembed/"],
    [
        "http://[^\\/\\s\\?&]+?.flickr.com/photos/[^\\/\\s\\?&]+?",
        "https://www.flickr.com/services/oembed/",
    ],
    [
        "https://[^\\/\\s\\?&]+?.flat.io/score/[^\\/\\s\\?&]+?",
        "https://flat.io/services/oembed",
    ],
    ["https://flat.io/score/[^\\/\\s\\?&]+?", "https://flat.io/services/oembed"],
    ["https://www.fite.tv/watch/[^\\/\\s\\?&]+?", "https://www.fite.tv/oembed"],
    [
        "https://faithlifetv.com/media/resource/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://faithlifetv.com/api/oembed",
    ],
    [
        "https://faithlifetv.com/media/assets/[^\\/\\s\\?&]+?",
        "https://faithlifetv.com/api/oembed",
    ],
    [
        "https://faithlifetv.com/media/[^\\/\\s\\?&]+?",
        "https://faithlifetv.com/api/oembed",
    ],
    [
        "https://faithlifetv.com/items/resource/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://faithlifetv.com/api/oembed",
    ],
    [
        "https://faithlifetv.com/items/[^\\/\\s\\?&]+?",
        "https://faithlifetv.com/api/oembed",
    ],
    [
        "https://app.getfader.com/projects/[^\\/\\s\\?&]+?/publish",
        "https://app.getfader.com/api/oembed",
    ],
    [
        "https://www.facebook.com/video.php",
        "https://www.facebook.com/plugins/video/oembed.json",
    ],
    [
        "https://www.facebook.com/[^\\/\\s\\?&]+?/videos/[^\\/\\s\\?&]+?",
        "https://www.facebook.com/plugins/video/oembed.json",
    ],
    [
        "https://www.facebook.com/notes/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://www.facebook.com/plugins/post/oembed.json",
    ],
    [
        "https://www.facebook.com/questions/[^\\/\\s\\?&]+?",
        "https://www.facebook.com/plugins/post/oembed.json",
    ],
    [
        "https://www.facebook.com/media/set\\?set=[^\\/\\s\\?&]+?",
        "https://www.facebook.com/plugins/post/oembed.json",
    ],
    [
        "https://www.facebook.com/permalink.php",
        "https://www.facebook.com/plugins/post/oembed.json",
    ],
    [
        "https://www.facebook.com/[^\\/\\s\\?&]+?/activity/[^\\/\\s\\?&]+?",
        "https://www.facebook.com/plugins/post/oembed.json",
    ],
    [
        "https://www.facebook.com/photo.php",
        "https://www.facebook.com/plugins/post/oembed.json",
    ],
    [
        "https://www.facebook.com/photo.php[^\\/\\s\\?&]+?",
        "https://www.facebook.com/plugins/post/oembed.json",
    ],
    [
        "https://www.facebook.com/[^\\/\\s\\?&]+?/photos/[^\\/\\s\\?&]+?",
        "https://www.facebook.com/plugins/post/oembed.json",
    ],
    [
        "https://www.facebook.com/photos/[^\\/\\s\\?&]+?",
        "https://www.facebook.com/plugins/post/oembed.json",
    ],
    [
        "https://www.facebook.com/[^\\/\\s\\?&]+?/posts/[^\\/\\s\\?&]+?",
        "https://www.facebook.com/plugins/post/oembed.json",
    ],
    ["https://eyrie.io/sparkfun/[^\\/\\s\\?&]+?", "https://eyrie.io/v1/oembed"],
    ["https://eyrie.io/board/[^\\/\\s\\?&]+?", "https://eyrie.io/v1/oembed"],
    ["https://ethfiddle.com/[^\\/\\s\\?&]+?", "https://ethfiddle.com/services/oembed/"],
    ["http://embedarticles.com/[^\\/\\s\\?&]+?", "http://embedarticles.com/oembed/"],
    [
        "http://egliseinfo.catholique.fr/[^\\/\\s\\?&]+?",
        "http://egliseinfo.catholique.fr/api/oembed",
    ],
    ["http://edocr.com/docs/[^\\/\\s\\?&]+?", "http://edocr.com/api/oembed"],
    ["https://d.tube/v/[^\\/\\s\\?&]+?", "https://api.d.tube/oembed"],
    ["http://dotsub.com/view/[^\\/\\s\\?&]+?", "http://dotsub.com/services/oembed"],
    ["http://docdro.id/[^\\/\\s\\?&]+?", "https://www.docdroid.net/api/oembed"],
    ["https://docdro.id/[^\\/\\s\\?&]+?", "https://www.docdroid.net/api/oembed"],
    [
        "http://[^\\/\\s\\?&]+?.docdroid.net/[^\\/\\s\\?&]+?",
        "https://www.docdroid.net/api/oembed",
    ],
    [
        "https://[^\\/\\s\\?&]+?.docdroid.net/[^\\/\\s\\?&]+?",
        "https://www.docdroid.net/api/oembed",
    ],
    [
        "http://www.dipity.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?/",
        "http://www.dipity.com/oembed/timeline/",
    ],
    [
        "https://www.ultimedia.com/default/index/videogeneric/id/[^\\/\\s\\?&]+?",
        "https://www.ultimedia.com/api/search/oembed",
    ],
    [
        "https://www.ultimedia.com/default/index/videogeneric/id/[^\\/\\s\\?&]+?/showtitle/1/viewnc/1",
        "https://www.ultimedia.com/api/search/oembed",
    ],
    [
        "https://www.ultimedia.com/central/video/edit/id/[^\\/\\s\\?&]+?/topic_id/[^\\/\\s\\?&]+?/",
        "https://www.ultimedia.com/api/search/oembed",
    ],
    [
        "https://[^\\/\\s\\?&]+?.didacte.com/a/course/[^\\/\\s\\?&]+?",
        "https://*.didacte.com/cards/oembed'",
    ],
    [
        'https://[^\\/\\s\\?&]+?.deviantart.com/[^\\/\\s\\?&]+?#/d[^\\/\\s\\?&]+?"',
        "http://backend.deviantart.com/oembed",
    ],
    ['https://sta.sh/[^\\/\\s\\?&]+?",', "http://backend.deviantart.com/oembed"],
    [
        "https://[^\\/\\s\\?&]+?.deviantart.com/[^\\/\\s\\?&]+?/art/[^\\/\\s\\?&]+?",
        "http://backend.deviantart.com/oembed",
    ],
    [
        "https://[^\\/\\s\\?&]+?.deviantart.com/art/[^\\/\\s\\?&]+?",
        "http://backend.deviantart.com/oembed",
    ],
    ["http://sta.sh/[^\\/\\s\\?&]+?", "http://backend.deviantart.com/oembed"],
    ["http://fav.me/[^\\/\\s\\?&]+?", "http://backend.deviantart.com/oembed"],
    [
        "http://[^\\/\\s\\?&]+?.deviantart.com/[^\\/\\s\\?&]+?#/d[^\\/\\s\\?&]+?",
        "http://backend.deviantart.com/oembed",
    ],
    [
        "http://[^\\/\\s\\?&]+?.deviantart.com/art/[^\\/\\s\\?&]+?",
        "http://backend.deviantart.com/oembed",
    ],
    [
        "https://[^\\/\\s\\?&]+?.deseretnews.com/[^\\/\\s\\?&]+?",
        "https://embed.deseretnews.com/",
    ],
    [
        "https://www.dailymotion.com/video/[^\\/\\s\\?&]+?",
        "https://www.dailymotion.com/services/oembed",
    ],
    [
        "http://www.dailymile.com/people/[^\\/\\s\\?&]+?/entries/[^\\/\\s\\?&]+?",
        "http://api.dailymile.com/oembed?format=json",
    ],
    [
        "https://app.cyranosystems.com/msg/[^\\/\\s\\?&]+?",
        "https://staging.cyranosystems.com/oembed",
    ],
    [
        "https://staging.cyranosystems.com/msg/[^\\/\\s\\?&]+?",
        "https://staging.cyranosystems.com/oembed",
    ],
    [
        "http://crowdranking.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "http://crowdranking.com/api/oembed.json",
    ],
    ["http://coub.com/embed/[^\\/\\s\\?&]+?", "http://coub.com/api/oembed.json"],
    ["http://coub.com/view/[^\\/\\s\\?&]+?", "http://coub.com/api/oembed.json"],
    ["https://commaful.com/play/[^\\/\\s\\?&]+?", "https://commaful.com/api/oembed/"],
    [
        "http://www.collegehumor.com/video/[^\\/\\s\\?&]+?",
        "http://www.collegehumor.com/oembed.json",
    ],
    ["https://codesandbox.io/embed/[^\\/\\s\\?&]+?", "https://codesandbox.io/oembed"],
    ["https://codesandbox.io/s/[^\\/\\s\\?&]+?", "https://codesandbox.io/oembed"],
    [
        "https://www.codepoints.net/[^\\/\\s\\?&]+?",
        "https://codepoints.net/api/v1/oembed",
    ],
    [
        "http://www.codepoints.net/[^\\/\\s\\?&]+?",
        "https://codepoints.net/api/v1/oembed",
    ],
    ["https://codepoints.net/[^\\/\\s\\?&]+?", "https://codepoints.net/api/v1/oembed"],
    ["http://codepoints.net/[^\\/\\s\\?&]+?", "https://codepoints.net/api/v1/oembed"],
    ["https://codepen.io/[^\\/\\s\\?&]+?", "http://codepen.io/api/oembed"],
    ["http://codepen.io/[^\\/\\s\\?&]+?", "http://codepen.io/api/oembed"],
    [
        "https://codehs.com/editor/share_abacus/[^\\/\\s\\?&]+?",
        "https://codehs.com/api/sharedprogram/*/oembed/",
    ],
    ["http://clyp.it/playlist/[^\\/\\s\\?&]+?", "http://api.clyp.it/oembed/"],
    ["http://clyp.it/[^\\/\\s\\?&]+?", "http://api.clyp.it/oembed/"],
    [
        "https://www.clipland.com/v/[^\\/\\s\\?&]+?",
        "https://www.clipland.com/api/oembed",
    ],
    [
        "http://www.clipland.com/v/[^\\/\\s\\?&]+?",
        "https://www.clipland.com/api/oembed",
    ],
    [
        "https://www.circuitlab.com/circuit/[^\\/\\s\\?&]+?",
        "https://www.circuitlab.com/circuit/oembed/",
    ],
    ["http://chirb.it/[^\\/\\s\\?&]+?", "http://chirb.it/oembed.json"],
    [
        "http://public.chartblocks.com/c/[^\\/\\s\\?&]+?",
        "http://embed.chartblocks.com/1.0/oembed",
    ],
    ["http://view.ceros.com/[^\\/\\s\\?&]+?", "http://view.ceros.com/oembed"],
    ["http://img.catbo.at/[^\\/\\s\\?&]+?", "http://img.catbo.at/oembed.json"],
    [
        "https://carbonhealth.com/practice/[^\\/\\s\\?&]+?",
        "http://carbonhealth.com/oembed",
    ],
    ["https://cacoo.com/diagrams/[^\\/\\s\\?&]+?", "http://cacoo.com/oembed.json"],
    ["https://cmc.byzart.eu/files/[^\\/\\s\\?&]+?", "https://cmc.byzart.eu/oembed/"],
    ["https://buttondown.email/[^\\/\\s\\?&]+?", "https://buttondown.email/embed"],
    [
        "https://view.briovr.com/api/v1/worlds/oembed/[^\\/\\s\\?&]+?",
        "https://view.briovr.com/api/v1/worlds/oembed/",
    ],
    [
        "https://blackfire.io/profiles/compare/[^\\/\\s\\?&]+?/graph",
        "https://blackfire.io/oembed",
    ],
    [
        "https://blackfire.io/profiles/[^\\/\\s\\?&]+?/graph",
        "https://blackfire.io/oembed",
    ],
    ["http://backtracks.fm/[^\\/\\s\\?&]+?", "https://backtracks.fm/oembed"],
    ["https://backtracks.fm/[^\\/\\s\\?&]+?", "https://backtracks.fm/oembed"],
    [
        "https://backtracks.fm/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?/e/[^\\/\\s\\?&]+?",
        "https://backtracks.fm/oembed",
    ],
    ["http://audiosnaps.com/k/[^\\/\\s\\?&]+?", "http://audiosnaps.com/service/oembed"],
    [
        "https://www.audiomack.com/playlist/[^\\/\\s\\?&]+?",
        "https://www.audiomack.com/oembed",
    ],
    [
        "https://www.audiomack.com/album/[^\\/\\s\\?&]+?",
        "https://www.audiomack.com/oembed",
    ],
    [
        "https://www.audiomack.com/song/[^\\/\\s\\?&]+?",
        "https://www.audiomack.com/oembed",
    ],
    [
        "https://audioclip.naver.com/audiobooks/[^\\/\\s\\?&]+?",
        "https://audioclip.naver.com/oembed",
    ],
    [
        "https://audioclip.naver.com/channels/[^\\/\\s\\?&]+?/clips/[^\\/\\s\\?&]+?",
        "https://audioclip.naver.com/oembed",
    ],
    [
        "https://app.archivos.digital/app/view/[^\\/\\s\\?&]+?",
        "https://app.archivos.digital/oembed/",
    ],
    [
        "https://renderer.apester.com/v2/[^\\/\\s\\?&]+?\\?preview=true&iframe_preview=true",
        "https://display.apester.com/oembed",
    ],
    ["http://animoto.com/play/[^\\/\\s\\?&]+?", "http://animoto.com/oembeds/create"],
    [
        "https://animatron.com/project/[^\\/\\s\\?&]+?",
        "https://animatron.com/oembed/json",
    ],
    [
        "https://www.animatron.com/project/[^\\/\\s\\?&]+?",
        "https://animatron.com/oembed/json",
    ],
    ["https://live.amcharts.com/[^\\/\\s\\?&]+?", "https://live.amcharts.com/oembed"],
    ["http://live.amcharts.com/[^\\/\\s\\?&]+?", "https://live.amcharts.com/oembed"],
    [
        "https://app.altrulabs.com/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?\\?answer_id=[^\\/\\s\\?&]+?",
        "https://api.altrulabs.com/social/oembed",
    ],
    [
        "https://photos.app.net/[^\\/\\s\\?&]+?/[^\\/\\s\\?&]+?",
        "https://alpha-api.app.net/oembed",
    ],
    [
        "https://alpha.app.net/[^\\/\\s\\?&]+?/post/[^\\/\\s\\?&]+?",
        "https://alpha-api.app.net/oembed",
    ],
    [
        "http://play.adpaths.com/experience/[^\\/\\s\\?&]+?",
        "http://play.adpaths.com/oembed/*",
    ],
    [
        "http://www.23hq.com/[^\\/\\s\\?&]+?/photo/[^\\/\\s\\?&]+?",
        "http://www.23hq.com/23/oembed",
    ],
]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import re

from micawber import Provider, ProviderRegistry, ProviderException

from pyunfurl.provider_data.noembed import NOEMBED_PROVIDER_LIST
from .provider_data.custom import CUSTOM_PROVIDER_LIST
from .provider_data.oembed import OEMBED_PROVIDER_LIST

__version__ = "0.0.0.1"
import micawber
import requests
from pyquery import PyQuery as pq
from uritools import urijoin, urisplit


def template(className, url, image, title, description, domain):
    return f"""<div class="unfurl {className}">
    <a rel="noopener nofollow" target="_blank" href="{url}">
        <img src="{image}">
    </a>
    <div class="unfurl-content">
        <a class="unfurl-title" href="{url}">{title}</a>
        <div>{description}</div>
        <a class="unfurl-domain" href="{url}">{domain}</a>
    </div>
</div>"""


def wrap_response(url, data, method):

    title = ("title" in data and data["title"]) or ""
    image = ("image" in data and data["image"]) or ""
    favicon = ("favicon" in data and data["favicon"]) or ""
    description = ("description" in data and data["description"]) or ""
    url = ("url" in data and data["url"]) or url
    css = ("css" in data and data["css"]) or ""

    if image:
        image = urijoin(url, image)

    if favicon:
        favicon = urijoin(url, favicon)

    domain = urisplit(url).authority
    if "domain" in data and data["domain"]:
        domain = data["domain"]
    site = data["title"]
    if "site_name" in data and data["site_name"]:
        site = data["site_name"]
    if "provider_name" in data and data["provider_name"]:
        site = data["provider_name"]

    if method == "oembed" or (method == "custom" and "html" in data and data["html"]):
        print(data)
        html = data["html"]
    else:
        if image:
            html = template("unfurl-image", url, image, title, description, domain)
        elif favicon:
            html = template(
                "unfurl-image unfurl-favicon", url, favicon, title, description, domain
            )
        else:
            html = template(
                "unfurl-image unfurl-default",
                url,
                "https://i.imgur.com/wQ37ilJ.png",
                title,
                description,
                domain,
            )

    return {
        "method": method,
        "site": site,
        "domain": domain,
        "title": title,
        "description": description,
        "image": image,
        "favicon": favicon,
        "url": url,
        "type": "rich",
        "html": html,
        "css": css,
    }


def updated_provider_list(list):
    if list == "OEMBED":
        providers = [
            [entry[0], entry[1].endpoint] for entry in micawber.bootstrap_basic()
        ]
        providers.extend(
            [[entry[0], entry[1].endpoint] for entry in micawber.bootstrap_oembed()]
        )
        return providers

    if list == "NOEMBED":
        return [[entry[0], entry[1].endpoint] for entry in micawber.bootstrap_noembed()]

    return []


def load_providers(provider_list="OEMBED", remote=False):
    provider = ProviderRegistry(None)

    if remote:
        providers = updated_provider_list(provider_list)
    else:
        providers = []
        if provider_list == "OEMBED":
            providers = OEMBED_PROVIDER_LIST
        if list == "NOEMBED":
            providers = NOEMBED_PROVIDER_LIST

    for entry in providers:
        provider.register(entry[0], Provider(entry[1]))

    return provider


def open_graph(url, timeout=15, html=None):

    if not html:
        html = requests.get(url, timeout=timeout).text

    d = pq(html)
    return {
        "type": d('meta[property="og:type"]').attr("content"),
        "url": d('meta[property="og:url"]').attr("content"),
        "title": d('meta[property="og:title"]').attr("content"),
        "site_name": d('meta[property="og:site_name"]').attr("content"),
        "description": d('meta[property="og:description"]').attr("content"),
        "image": d('meta[property="og:image"]').attr("content"),
        "audio": d('meta[property="og:audio"]').attr("content"),
        "locale": d('meta[property="og:locale"]').attr("content"),
        "video": d('meta[property="og:video"]').attr("content"),
    }


def twitter_card(url, timeout=15, html=None):

    if not html:
        html = requests.get(url, timeout=timeout).text

    d = pq(html)
    return {
        "card": d('meta[name="twitter:card"]').attr("content"),
        "url": d('meta[name="twitter:url"]').attr("content"),
        "site_name": d('meta[name="twitter:site"]').attr("content"),
        "creator": d('meta[name="twitter:creator"]').attr("content"),
        "description": d('meta[name="twitter:description"]').attr("content"),
        "image": d('meta[name="twitter:image"]').attr("content"),
        "title": d('meta[name="twitter:title"]').attr("content"),
    }


def meta_tags(url, timeout=15, html=None):
    if not html:
        html = requests.get(url, timeout=timeout).text

    d = pq(html)
    favicon = d('link[rel="shortcut icon"]').attr("href")
    if not favicon:
        favicon_url = urijoin(url, "/favicon.ico")
        r = requests.head(favicon_url)
        if r.status_code == 200:
            favicon = favicon_url

    return {
        "title": d('meta[name="title"]').attr("content") or d("title").text(),
        "description": d('meta[name="description"]').attr("content"),
        "image": d('meta[name="image"]').attr("content"),
        "favicon": favicon,
        "url": d('meta[name="canonical"]').attr("content")
        or d('meta[name="url"]').attr("content"),
        "keywords": d('meta[name="keywords"]').attr("content"),
    }


def oembed(url, timeout=15, html=None, refresh_oembed_provider_list=False):
    try:
        embed = load_providers("OEMBED", refresh_oembed_provider_list).request(url)
        if embed and "html" in embed:
            return embed
    except ProviderException:
        pass

    try:
        embed = load_providers("NOEMBED", refresh_oembed_provider_list).request(url)
        if embed and "html" in embed:
            return embed
    except ProviderException:
        pass

    try:
        if not html:
            html = requests.get(url, timeout=timeout).text

        d = pq(html)
        oembed_url = d('link[type="application/json+oembed"]').attr("href")
        if oembed_url:
            return requests.get(oembed_url, timeout=timeout).json()
    except requests.exceptions.RequestException as e:
        return None

    return None


def extend_dict(d1, d2):
    result = d2.copy()
    result.update({k: v for k, v in d1.items() if v})
    return result


def completed(data):
    return data["title"] and data["description"] and data["image"] and data["url"]


def custom_unfurl(url, timeout=15, html=None):
    for regex, provider in CUSTOM_PROVIDER_LIST:
        if re.match(regex, url):
            return provider(url, timeout, html)

    return None


def unfurl(url, timeout=15, html=None, refresh_oembed_provider_list=False):
    """
    :param url: The url to embed
    :param timeout: Timeout (in seconds) to allow url to load
    :param html: If you already have the html available you can pass it in to save a network call
    :param refresh_oembed_provider_list: Set to True to reload the provider list from oembed.com, otherwise
    the list that is included with pyunfurl is used
    :return: dict
    """

    data = custom_unfurl(url, timeout, html)
    if data:
        return wrap_response(url, data, "custom")

    data = oembed(url, timeout, html, refresh_oembed_provider_list)
    if data:
        return wrap_response(url, data, "oembed")

    data = twitter_card(url, timeout, html)
    if completed(data):
        return wrap_response(url, data, "twitter_card")

    data = extend_dict(data, open_graph(url, timeout, html))
    if completed(data):
        return wrap_response(url, data, "open_graph")

    data = extend_dict(data, meta_tags(url, timeout, html))
    return wrap_response(url, data, "meta_tags")



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# For a fully annotated version of this file and what it does, see
# https://github.com/pypa/sampleproject/blob/master/setup.py

# To upload this file to PyPI you must build it then upload it:
# python setup.py sdist bdist_wheel  # build in 'dist' folder
# python-m twine upload dist/*  # 'twine' must be installed: 'pip install twine'


import io
import os
from setuptools import find_packages, setup

DEPENDENCIES = ['pyquery', 'requests', 'uritools', 'micawber']
EXCLUDE_FROM_PACKAGES = ["contrib", "docs", "tests*"]
CURDIR = os.path.abspath(os.path.dirname(__file__))

with io.open(os.path.join(CURDIR, "README.md"), "r", encoding="utf-8") as f:
    README = f.read()


setup(
    name="pyunfurl",
    version='0.1.1',
    author="Loftie Ellis",
    author_email="pyunfurl@unfurl.dev",
    description="library for embedding ('unfurling') content from other sites into your own site",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/lpellis/pyunfurl",
    packages=find_packages(exclude=EXCLUDE_FROM_PACKAGES),
    include_package_data=True,
    install_requires=DEPENDENCIES,
    test_suite="tests.test_project",
    python_requires=">=3.6",
    # license and classifier list:
    # https://pypi.org/pypi?%3Aaction=list_classifiers
    license="License :: OSI Approved :: MIT License",
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)
